@@ -1,5 +1,5 @@
 /*
-	htpdate v1.2.1
+	htpdate v1.2.2
 
 	Eddy Vervest <eddy@vervest.org>
 	http://www.vervest.org/htp
@@ -14,11 +14,11 @@
 	Debug mode (shows raw timestamps, round trip time (RTT) and
 	time difference):
 
-	~# htpdate -d www.linux.org www.freebsd.org
+	~# htpdate -d www.example.com
 
 	Adjust time smoothly:
 
-	~# htpdate -a www.linux.org www.freebsd.org
+	~# htpdate -a www.example.com
 
 	...see man page for more details
 
@@ -52,7 +52,7 @@
 #include <pwd.h>
 #include <grp.h>
 
-#define VERSION 				"1.2.1"
+#define VERSION 				"1.2.2"
 #define	MAX_HTTP_HOSTS			15				/* 16 web servers */
 #define	DEFAULT_HTTP_PORT		"80"
 #define	DEFAULT_PROXY_PORT		"8080"
